<?php

add_action( 'after_setup_theme', 'soren_i18n' );
/**
 * Load the child theme textdomain for internationalization.
 *
 * Must be loaded before Genesis Framework /lib/init.php is included.
 * Translations can be filed in the /languages/ directory.
 *
 * @since 1.2.0
 */
function soren_i18n() {
    load_child_theme_textdomain( 'soren', get_stylesheet_directory() . '/languages' );
}

add_action( 'wp_enqueue_scripts', 'wsm_enqueue_assets' );
/**
 * Enqueue theme assets.
 */
function wsm_enqueue_assets() {
  wp_enqueue_style( 'soren', get_stylesheet_uri() );
  wp_style_add_data( 'soren', 'rtl', 'replace' );
}

// Start the engine
require_once(TEMPLATEPATH.'/lib/init.php');

// Remove Edit link
add_filter( 'edit_post_link', '__return_false' );

// Add New Theme Settings
require_once( CHILD_DIR . '/lib/admin/wsm-theme-settings.php' );

/** Add Viewport meta tag for mobile browsers */
add_action( 'genesis_meta', 'add_viewport_meta_tag' );
function add_viewport_meta_tag() {
    echo '<meta name="viewport" content="width=device-width, initial-scale=1.0"/>';
}

/** Create additional color style options */
add_theme_support( 'genesis-style-selector', array(
  'soren-blue-white' => __( 'Blue on White', 'soren' ),
  'soren-orange-white' => __( 'Orange on White', 'soren' ),
  'soren-green-tan' => __( 'Green on Tan', 'soren' ),
  'soren-green-gray' => __( 'Green on Gray', 'soren' ),
  'soren-red-gray' => __( 'Red on Gray', 'soren' ),
  'soren-teal-gray' => __( 'Teal on Gray', 'soren' ),
  ) );


// Force Stupid IE to NOT use compatibility mode
add_action('wp_head','wsm_keep_ie_modern');
function wsm_keep_ie_modern() {
	echo '<meta http-equiv="X-UA-Compatible" content="IE=edge" />'."\n";
}

// Add new image sizes
//add_image_size('Blog Thumbnail', 245, 115, TRUE);

// Customize the Search Box
add_filter('genesis_search_button_text', 'custom_search_button_text');
function custom_search_button_text($text) {
    return esc_attr('Go');
}

// Modify the author box title
add_filter('genesis_author_box_title', 'soren_author_box_title');
function soren_author_box_title($title) {
    $title = sprintf( '<h4>%s</h4><strong class="authorbox-title">%s</strong>', __('About the Author', 'soren'), get_the_author_meta('display_name') );
    return $title;
}

// Modify the size of the Gravatar in the author box
add_filter( 'genesis_author_box_gravatar_size', 'soren_author_box_gravatar_size' );
function soren_author_box_gravatar_size($size) {
    return '90';
}

// Customize the post meta function
add_filter( 'genesis_post_meta', 'post_meta_filter' );
function post_meta_filter($post_meta) {
	if (!is_page()) {
    	$post_meta = '[post_categories sep=", " before="<div class=\'post-categories\'>' . __( 'Posted in:', 'soren' ) . ' " after="</div>"] [post_tags sep=", " before="<div class=\'post-tags\'>' . __( 'Tags:', 'soren' ) . ' " after="</div>"]';
    	return $post_meta;
	}
}

// Add Read More button to blog page and archives
add_filter( 'excerpt_more', 'wsm_add_excerpt_more' );
add_filter( 'get_the_content_more_link', 'wsm_add_excerpt_more' );
add_filter( 'the_content_more_link', 'wsm_add_excerpt_more' );
function wsm_add_excerpt_more( $more ) {
    return '<div class="more-link"><a href="' . get_permalink() . '" rel="nofollow">' . __( 'Read More', 'soren' ) . '</a></div>';
}

/*
 * Add support for targeting individual browsers via CSS
 * See readme file located at /lib/js/css_browser_selector_readm.html
 * for a full explanation of available browser css selectors.
 */
add_action('get_header', 'wsm_load_scripts');
function wsm_load_scripts() {
    wp_enqueue_script('browserselect', CHILD_URL.'/lib/js/css_browser_selector.js', array('jquery'), '0.4.0', TRUE);
}

// Structural Wrap
add_theme_support( 'genesis-structural-wraps', array( 'header', 'nav', 'subnav', 'inner', 'footer-widgets', 'footer' ) );

// Setup Widgets
include_once( CHILD_DIR . '/lib/widgets/call-to-action.php');
include_once( CHILD_DIR . '/lib/widgets/widget-social.php');
include_once( CHILD_DIR . '/lib/widgets/wsm-featured-page.php');

//include extras
include_once( CHILD_DIR . '/lib/functions/post-types.php');
include_once( CHILD_DIR . '/lib/functions/metaboxes.php');

/// Add footer navigation menu
register_nav_menus( array(
	'footer' => __('Footer Navigation Menu', 'soren')
) );

// Remove Unused Page Layouts
genesis_unregister_layout( 'content-sidebar-sidebar' );
genesis_unregister_layout( 'sidebar-sidebar-content' );
genesis_unregister_layout( 'sidebar-content-sidebar' );

// Setup Shortcodes
include_once( CHILD_DIR . '/lib/functions/shortcodes.php');

// Replace Footer With Custom Footer
remove_action('genesis_footer', 'genesis_do_footer');
add_action('genesis_footer', 'custom_footer');
function custom_footer() {
    require(CHILD_DIR.'/lib/structure/footer.php');
}


// Setup Sidebars
unregister_sidebar('sidebar-alt');

genesis_register_sidebar( array(
	'id'			=> 'blog-sidebar',
	'name'			=> __( 'Blog Sidebar', 'soren' ),
	'description'	=> __( 'This is the Blog Page Sidebar.', 'soren' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'rotator',
	'name'			=> __( 'Rotator', 'soren' ),
	'description'	=> __( 'This is the image rotator section.', 'soren' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-top-left',
	'name'			=> __( 'Home Top Left', 'soren' ),
	'description'	=> __( 'This is the Home Top Left widget area.', 'soren' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-top-center',
	'name'			=> __( 'Home Top Center', 'soren' ),
	'description'	=> __( 'This is the Home Top Center widget area.', 'soren' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-top-right',
	'name'			=> __( 'Home Top Right', 'soren' ),
	'description'	=> __( 'This is the Home Top Right widget area.', 'soren' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-bottom-left',
	'name'			=> __( 'Home Bottom Left', 'soren' ),
	'description'	=> __( 'This is the Home Bottom Left widget area.', 'soren' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-bottom-center',
	'name'			=> __( 'Home Bottom Center', 'soren' ),
	'description'	=> __( 'This is the Home Bottom Center widget area.', 'soren' ),
) );
genesis_register_sidebar( array(
	'id'			=> 'home-bottom-right',
	'name'			=> __( 'Home Bottom Right', 'soren' ),
	'description'	=> __( 'This is the Home Bottom Right widget area.', 'soren' ),
) );

// Replace Primary sidebar with Blog Page sidebar on blog pages
include_once(CHILD_DIR.'/lib/structure/sidebar.php');

//because plugin loads this on init
add_filter('be_flex_slider_settings', 'soren_flexslider_options');
function soren_flexslider_options($flex_settings){
    $extra_settings = array(
	'directionNav' => 'false',
	'controlNav' => 'false'

	);
    $flex_settings = array_merge($extra_settings, $flex_settings);
    return $flex_settings;
}

/*
 *
 * Functions and styling for Home Page image rotator
 *
 */

// Admin Preview on Settings > WP Rotator
remove_action('admin_head','wp_rotator_css');
add_action('admin_head','custom_rotator_css');

// Public facing styles added to home page
remove_action('wp_head','wp_rotator_css');
add_action('wp_head','custom_rotator_css');

function custom_rotator_css() {
  if ( is_home() ) {
  global $bsd_pane_width;
  global $bsd_pane_height;
?>
<style type="text/css">

.flexslider {
  padding: 7px; margin: 0;
   border:1px solid #ACB2BC;
   border-radius: 8px;
   width: 96%;
}

.flexslider .pane {
  height: <?php echo $bsd_pane_height; ?>px;
  width: <?php echo $bsd_pane_width; ?>px;
  overflow: hidden;
  position: relative;
  padding: 0px;
  margin: 0px;
}

.flexslider .elements {
  height: <?php echo $bsd_pane_height; ?>px;
  padding: 0px;
  margin: 0px;
}

.flexslider .featured-cell {
  width: <?php echo $bsd_pane_width; ?>px;
  height: <?php echo $bsd_pane_height; ?>px;

  <?php if ((function_exists(wp_rotator_option)) && (wp_rotator_option('animate_style') == 'fade')): ?>
    display: block;
    position: absolute;
    top: 0;
    left: 0;

  <?php else: ?>
    display: inline;
    position: relative;
    float: left;
  <?php endif; ?>
  margin: 0px;
  padding: 0px;
}

.flexslider .featured-cell .image {
  position: absolute;
  top: 0;
  left: 0;
}

.flexslider .featured-cell .info {
  position: absolute;
  left: 0;
  bottom: 10px;
  width: <?php echo $bsd_pane_width; ?>px;
  height: 50px;
  padding: 8px 8px;
  overflow: hidden;
  background: url(<?php echo get_stylesheet_directory_uri() . '/images/feature-bg.png'; ?> ) transparent;
  color: #fff;
}

.flexslider .current-cell { z-index: 500; }

@media only screen and (max-width: 960px) {
        .flexslider{width:69%;margin:0 auto;}
}
</style>
<?php
}}

