<?php

// Define our constants
define( 'WSM_SETTINGS_FIELD', 'wsm' );

// Setup some Defaults
function wsm_default_theme_options() {
	$options = array(
		'wsm_header_height' => 100,
		'wsm_homepage_headline' => 'Place Your Home Page Headline Here',
		'wsm_company_name' => 'company name',
		'wsm_street_address' => '1234 Street Address',
		'wsm_city_state_zip' => 'City, State 12345',
		'wsm_copyright' => 'company, all rights reserved'
	);
	return apply_filters( 'wsm_default_theme_options', $options );
}

// Sanatize inputs for security purposes
add_action( 'genesis_settings_sanitizer_init', 'wsm_register_theme_sanitization_filters' );

function wsm_register_theme_sanitization_filters() {
	genesis_add_option_filter( 'no_html', WSM_SETTINGS_FIELD,
	array(
		'wsm_header_height',
		'wsm_homepage_headline',
		'wsm_company_name',
		'wsm_street_address',
		'wsm_city_state_zip',
		'wsm_copyright'
	) );
	
	genesis_add_option_filter('safe_html', GENESIS_SETTINGS_FIELD,
	array(
		'footer_disclaimer'
	));

}

// Initialize the meta boxes on the Soren Settings Page
function wsm_settings_boxes() {
	global $_wsm_settings_pagehook;
	add_meta_box( 'wsm-header-height', __( 'Header Settings', 'soren' ), 'wsm_header_metabox', $_wsm_settings_pagehook, 'main', 'high' );
	add_meta_box('wsm-homepage-h1', __( 'Home Page H1 Headline', 'soren' ), 'wsm_homepage_h1_settings_box', $_wsm_settings_pagehook, 'main', 'high');
	add_meta_box('wsm-footer-settings', __( 'Footer Area Content', 'soren' ), 'wsm_footer_settings_box', $_wsm_settings_pagehook, 'main', 'high');
}

// Header Height settings box
function wsm_header_metabox() { ?>

	<p><?php _e('Header Height', 'soren'); ?>:<br />
	<input type="text" name="<?php echo WSM_SETTINGS_FIELD; ?>[wsm_header_height]" value="<?php echo genesis_get_option( 'wsm_header_height', WSM_SETTINGS_FIELD ); ?>" size="10" /></p>

<?php }

// Home page H1 settings box
function wsm_homepage_h1_settings_box() {
?>

	<p><?php _e('Home Page H1 Headline', 'soren'); ?>:<br />
	<input type="text" name="<?php echo WSM_SETTINGS_FIELD; ?>[wsm_homepage_headline]" value="<?php echo genesis_get_option( 'wsm_homepage_headline', WSM_SETTINGS_FIELD ); ?>" size="90" /></p>

<?php }

// Footer settings box
function wsm_footer_settings_box() {
?>

	<p><?php _e('Company Name', 'soren'); ?>:</p>
	<input type="text" name="<?php echo WSM_SETTINGS_FIELD; ?>[wsm_company_name]" value="<?php echo genesis_get_option( 'wsm_company_name', WSM_SETTINGS_FIELD ); ?>" size="50" /></p>
	
	<p><?php _e('Street Address', 'soren'); ?>:</p>
	<input type="text" name="<?php echo WSM_SETTINGS_FIELD; ?>[wsm_street_address]" value="<?php echo genesis_get_option( 'wsm_street_address', WSM_SETTINGS_FIELD ); ?>" size="50" /></p>
	
	<p><?php _e('City, State and Zip Code', 'soren'); ?>:</p>
	<input type="text" name="<?php echo WSM_SETTINGS_FIELD; ?>[wsm_city_state_zip]" value="<?php echo genesis_get_option( 'wsm_city_state_zip', WSM_SETTINGS_FIELD ); ?>" size="50" /></p>
	
	<p><?php _e('Copyright Text', 'soren'); ?>:</p>
	<input type="text" name="<?php echo WSM_SETTINGS_FIELD; ?>[wsm_copyright]" value="<?php echo genesis_get_option( 'wsm_copyright', WSM_SETTINGS_FIELD ); ?>" size="50" /></p>
	
<?php }

/***********************************************************/
// Don't edit below here or the sky will fall on your head //
/***********************************************************/

add_action( 'admin_init', 'wsm_register_settings' );
function wsm_register_settings() {
	register_setting( WSM_SETTINGS_FIELD, WSM_SETTINGS_FIELD );
	add_option( WSM_SETTINGS_FIELD, wsm_default_theme_options() );
	
	if ( genesis_get_option( 'reset', WSM_SETTINGS_FIELD ) ) {
		update_option( WSM_SETTINGS_FIELD, wsm_default_theme_options() );
		genesis_admin_redirect( WSM_SETTINGS_FIELD, array( 'reset' => 'true' ) );
		exit;
	}
}

add_action( 'admin_notices', 'wsm_theme_settings_notice' );

function wsm_theme_settings_notice() {
	if ( ! isset( $_REQUEST['page'] ) || $_REQUEST['page'] != WSM_SETTINGS_FIELD )
		return;

	if ( isset( $_REQUEST['reset'] ) && 'true' == $_REQUEST['reset'] )
		echo '<div id="message" class="updated"><p><strong>' . __( 'Settings reset.', 'genesis' ) . '</strong></p></div>';
	elseif ( isset( $_REQUEST['settings-updated'] ) && 'true' == $_REQUEST['settings-updated'] )
		echo '<div id="message" class="updated"><p><strong>' . __( 'Settings saved.', 'genesis' ) . '</strong></p></div>';
}

add_action( 'admin_menu', 'wsm_theme_options' );

function wsm_theme_options() {
	global $_wsm_settings_pagehook;
	$_wsm_settings_pagehook = add_submenu_page( 'genesis', 'Soren Settings', 'Soren Settings', 'edit_theme_options', WSM_SETTINGS_FIELD, 'wsm_theme_options_page' );

	add_action( 'load-'.$_wsm_settings_pagehook, 'wsm_settings_scripts' );
	add_action( 'load-'.$_wsm_settings_pagehook, 'wsm_settings_boxes' );
}


function wsm_settings_scripts() {	
	global $_wsm_settings_pagehook;
	wp_enqueue_script( 'common' );
	wp_enqueue_script( 'wp-lists' );
	wp_enqueue_script( 'postbox' );
}

add_filter( 'screen_layout_columns', 'wsm_settings_layout_columns', 10, 2 );

function wsm_settings_layout_columns( $columns, $screen ) {
	global $_wsm_settings_pagehook;
	if ( $screen == $_wsm_settings_pagehook ) {
		$columns[$_wsm_settings_pagehook] = 1;
	}
	return $columns;
}


function wsm_theme_options_page() { 

	global $_wsm_settings_pagehook, $screen_layout_columns;
	$width = "width: 99%;";
	$hide2 = $hide3 = " display: none;";
	?>	
	
	<div id="ctsettings" class="wrap genesis-metaboxes">
		<form method="post" action="options.php">
		
			<?php wp_nonce_field( 'closedpostboxes', 'closedpostboxesnonce', false ); ?>
			<?php wp_nonce_field( 'meta-box-order', 'meta-box-order-nonce', false ); ?>
			<?php settings_fields( WSM_SETTINGS_FIELD ); ?>
			
			<?php screen_icon( 'options-general' ); ?>
			
			<h2>
				<?php _e( 'Soren Settings', 'genesis' ); ?>
				<input type="submit" class="button-primary genesis-h2-button" value="<?php _e( 'Save Settings', 'genesis' ) ?>" />
				<input type="submit" class="button-highlighted genesis-h2-button" name="<?php echo WSM_SETTINGS_FIELD; ?>[reset]" value="<?php _e( 'Reset Settings', 'genesis' ); ?>" onclick="return genesis_confirm('<?php echo esc_js( __( 'Are you sure you want to reset?', 'genesis' ) ); ?>');" />
			</h2>
		
			<div class="metabox-holder">
				<div class="postbox-container" style="<?php echo $width; ?>">
					<?php do_meta_boxes( $_wsm_settings_pagehook, 'main', null ); ?>
				</div>
			</div>
		
		</form>
	</div>
	<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready( function($) {
			// close postboxes that should be closed
			$('.if-js-closed').removeClass('if-js-closed').addClass('closed');
			// postboxes setup
			postboxes.add_postbox_toggles('<?php echo $_wsm_settings_pagehook; ?>');
		});
		//]]>
	</script>

<?php }